#!/usr/bin/python

import sys, getopt

def main():
    print('Welcome to Python Phast Web Services')

def method2():
    print('This is method 2')

if __name__ == "__main__":
    main()